Module hashmap

Module hashmap 

Inline HashMap

Structs

InlineHashMap
Similar to InlineVec, this structure will use an array if it is small enough to live on the stack, otherwise it allocates a HashMap on the heap
InlineHashMapIterator
An iterator over the inline array elements of an InlineHashMap.
InlineHashMapIteratorMut
An iterator over the inline array elements of an InlineHashMap.

Enums

Iter
Iterator over an inline map, with an optional heap-backed variant in std builds.