Inline vector
Structs
- Inline
Vec - A wrapper around a
Vec<T>that lives on the stack if it is small enough. - Inline
VecIter - An iterator over the elements stored in an
InlineVec
Inline vector
Vec<T> that lives on the stack if it is small enough.InlineVec