pub struct Bytes<'a> { /* private fields */ }Expand description
A storage type for raw bytes, used by the parser
Implementations
Sourceimpl<'a> Bytes<'a>
impl<'a> Bytes<'a>
Sourcepub fn as_utf8_str(&self) -> Cow<'_, str>
pub fn as_utf8_str(&self) -> Cow<'_, str>
Convenient method for lossy-encoding the data as UTF8
Sourcepub fn try_as_utf8_str(&self) -> Option<&str>
pub fn try_as_utf8_str(&self) -> Option<&str>
Tries to convert the inner data to a &str, without allocating in the case
that the inner data is not valid UTF8
Sourcepub fn as_bytes_borrowed(&self) -> Option<&'a [u8]>
pub fn as_bytes_borrowed(&self) -> Option<&'a [u8]>
Returns the raw data referenced by this struct
The lifetime of the returned data is tied to ’a, unlike Bytes::as_bytes
which has a lifetime of ’_ (self) in case it is owned