pub type RawChildren = InlineVec<NodeHandle, INLINED_SUBNODES>;Expand description
The type of vector for children of an HTML tag
Aliased Type
pub struct RawChildren(/* private fields */);pub type RawChildren = InlineVec<NodeHandle, INLINED_SUBNODES>;The type of vector for children of an HTML tag
pub struct RawChildren(/* private fields */);