Re-exports
pub use errors::ParseError;
Modules
- errors
- Errors that occur throughout the crate
- inline
- Inline data structures
- queryselector
- Query selector API
Structs
- Attributes
- Stores all attributes of an HTML tag, as well as additional metadata such as
idandclass - Bytes
- A storage type for raw bytes, used by the parser
- Children
- A thin wrapper around the children of
HTMLTag - Children
Mut - A thin mutable wrapper around the children of
HTMLTag - HTMLTag
- Represents a single HTML element
- Node
Handle - A detached, external handle to a HTML node, originally obtained from a Parser
- Parser
- The main HTML parser
- Parser
Options - Options for the HTML Parser
- VDom
- VDom represents a Document Object Model
- VDom
Guard - A RAII guarded version of VDom
Enums
- HTML
Version - HTML Version ()
- Node
- An HTML Node
Functions
- parse
- Parses the given input string
- parse_
owned ⚠ - Parses the given input string and returns an owned, RAII guarded DOM
- parse_
query_ selector - Parses a query selector
Type Aliases
- Class
Vec - Inline class vector
- Inner
Node Handle - The inner type of a NodeHandle, used to represent an index into the tags table
- RawAttributes
Map - The type of map for “raw” attributes
- RawChildren
- The type of vector for children of an HTML tag
- Tree
- A list of HTML nodes