Inline HashMap
Structs
- Inline
Hash Map - Similar to InlineVec, this structure will use an array if it is small enough to live on the stack, otherwise it allocates a HashMap on the heap
- Inline
Hash MapIterator - An iterator over the inline array elements of an
InlineHashMap. - Inline
Hash MapIterator Mut - An iterator over the inline array elements of an
InlineHashMap.