pub struct VDomGuard { /* private fields */ }Expand description
A RAII guarded version of VDom
The input string is freed once this struct goes out of scope.
The only way to construct this is by calling parse_owned().
Implementations
Sourceimpl VDomGuard
impl VDomGuard
Sourcepub fn get_ref<'a>(&'a self) -> &'a VDom<'a>
pub fn get_ref<'a>(&'a self) -> &'a VDom<'a>
Returns a reference to the inner DOM.
The lifetime of the returned VDom is bound to self so that elements cannot outlive this VDomGuard struct.
Sourcepub fn get_mut_ref<'a, 'b: 'a>(&'b mut self) -> &'b VDom<'a>
pub fn get_mut_ref<'a, 'b: 'a>(&'b mut self) -> &'b VDom<'a>
Returns a mutable reference to the inner DOM.
The lifetime of the returned VDom is bound to self so that elements cannot outlive this VDomGuard struct.